# Generated by roxygen2: do not edit by hand

export(CI.IQR)
export(CI.MAD)
export(CI.fisherkurtosis)
export(CI.fisherskew)
export(CI.gmean)
export(CI.hmean)
export(CI.mean)
export(CI.meanNArm)
export(CI.median)
export(CI.pearsonskew)
export(CI.sd)
export(CI.var)
export(CIwithDF.mean)
export(CousineauLaurencelleLambda)
export(GRD)
export(HyunhFeldtEpsilon)
export(MAD)
export(MauchlySphericityTest)
export(Rexpression)
export(SE.IQR)
export(SE.MAD)
export(SE.fisherkurtosis)
export(SE.fisherskew)
export(SE.gmean)
export(SE.hmean)
export(SE.mean)
export(SE.meanNArm)
export(SE.median)
export(SE.pearsonskew)
export(SE.sd)
export(SE.var)
export(ShroutFleissICC1)
export(ShroutFleissICC11)
export(ShroutFleissICC1k)
export(WelchDegreeOfFreedom)
export(WinerCompoundSymmetryTest)
export(biasCorrectionTransform)
export(bootstrapPI.gmean)
export(bootstrapPI.hmean)
export(bootstrapPI.mean)
export(bootstrapPI.median)
export(bootstrapPI.sd)
export(bootstrapPI.var)
export(bootstrapSE.gmean)
export(bootstrapSE.hmean)
export(bootstrapSE.mean)
export(bootstrapSE.median)
export(bootstrapSE.sd)
export(bootstrapSE.var)
export(custom)
export(extent)
export(fisherkurtosis)
export(fisherskew)
export(geom_flat_violin)
export(geom_superberrorbar)
export(gmean)
export(has.cbind.terms)
export(has.crange.terms)
export(has.nested.terms)
export(hmean)
export(in.formula)
export(is.formula)
export(is.one.sided)
export(makeTransparent)
export(meanNArm)
export(pearsonskew)
export(poolSDTransform)
export(runDebug)
export(showHorizontalSignificance)
export(showSignificance)
export(showVerticalSignificance)
export(slope)
export(sub.formulas)
export(subjectCenteringTransform)
export(superb)
export(superbData)
export(superbPlot)
export(superbPlot.bar)
export(superbPlot.boxplot)
export(superbPlot.circularline)
export(superbPlot.circularlineBand)
export(superbPlot.circularpoint)
export(superbPlot.circularpointjitter)
export(superbPlot.circularpointlinejitter)
export(superbPlot.corset)
export(superbPlot.halfwidthline)
export(superbPlot.line)
export(superbPlot.lineBand)
export(superbPlot.point)
export(superbPlot.pointindividualline)
export(superbPlot.pointjitter)
export(superbPlot.pointjitterviolin)
export(superbPlot.pointlinejitter)
export(superbPlot.raincloud)
export(superbShiny)
export(superbToWide)
export(twoStepTransform)
import(MASS)
import(ggplot2)
import(shiny)
import(shinyBS)
import(stats)
importFrom(Rdpack,reprompt)
importFrom(foreign,read.spss)
importFrom(lsr,wideToLong)
importFrom(methods,existsFunction)
importFrom(plyr,ddply)
importFrom(reshape2,dcast)
importFrom(rrapply,rrapply)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace_all)
importFrom(utils,capture.output)
importFrom(utils,modifyList)
